Module connection

Module connection 

Structs

SqliteConnection
Connection wrapper backed by a bb8 pooled SQLite connection.

Functions

apply_wal_pragmas
Apply WAL pragmas to a pooled connection.
dml
Adapter for query builder dml (typed-sqlite target).
dml_with_cache_mode
Adapter for query builder dml with explicit statement cache mode.
select
Adapter for query builder select (typed-sqlite target).
select_with_cache_mode
Adapter for query builder select with explicit statement cache mode.