dml_with_cache_mode

Function dml_with_cache_mode 

pub async fn dml_with_cache_mode(
    conn: &mut PooledConnection<'static, SqliteManager>,
    query: &str,
    params: &[RowValues],
    statement_cache_mode: StatementCacheMode,
) -> Result<usize, SqlMiddlewareDbError>
Adapter for query builder dml with explicit statement cache mode.

Errors

Returns SqlMiddlewareDbError if converting parameters or executing the statement fails.